@@ -35,19 +35,13 @@ def test_user_2():
 def test_invalid_user():
     result = runner.invoke(app, ["--user", "Camila", "50"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "Option '--user' requires 3 arguments" in result.output
-        or "--user option requires 3 arguments" in result.output
-    )
+    assert "Option '--user' requires 3 arguments" in result.output
 
 
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
